@@ -1,11 +1,12 @@
 from cryptmoji.data import LENGTH, emojis
+from hashlib import sha512
 
 
 class Cryptmoji:
     def __init__(self, text: str, key: str = None):
         self.text = [i for i in text]
-        self.key = key
-        self.key_len = len(key) if key is not None else 0
+        self.key = sha512(str(key))
+        self.key_len = len(key)
 
     def encrypt(self) -> str:
         """
